@@ -156,7 +156,7 @@ class Client:
         ret = []
         for tx in txs:
             tx = DictObj(tx)
-            tx.success = (tx.vm_status == 'executed')
+            tx.success = (tx.vm_status.type == 'executed')
             ret.append(tx)
         return ret
 
@@ -248,7 +248,7 @@ class Client:
                 if len(ret.events) == 0:
                     if self.verbose:
                         print("no events emitted")
-                major_status = ret.vm_status
+                major_status = ret.vm_status.type
                 if major_status != 'executed':
                     from libra.vm_error import StatusCode
                     raise VMError(major_status, StatusCode.get_name(major_status))
