@@ -1,4 +1,4 @@
-from canoser import Uint64, hex_to_int_list
+from canoser import Uint64
 from libra_client.cli.command import Command, blocking_cmd
 
 
@@ -21,9 +21,9 @@ class TransferCommand(Command):
             self.print_params_help()
             return
         if len(params) == 5:
-            metadata = hex_to_int_list(params[4])
+            metadata = bytes.fromhex(params[4])
         else:
-            metadata = None
+            metadata = b''
         if len(params) == 6:
             gas_unit_price_in_micro_libras = Uint64.int_safe(params[5])
         else:
@@ -34,15 +34,19 @@ class TransferCommand(Command):
             max_gas_amount_in_micro_libras = 400_000
         print(">> Transferring")
         is_blocking = blocking_cmd(params[0])
-        sequence_number = client.transfer_coins(params[1], params[2], params[3],
-                                                max_gas_amount_in_micro_libras, gas_unit_price_in_micro_libras, is_blocking, metadata)
+        sequence_number = client.transfer_coins(
+            params[1], params[2], params[3],
+            max_gas_amount=max_gas_amount_in_micro_libras,
+            gas_unit_price=gas_unit_price_in_micro_libras,
+            is_blocking=is_blocking,
+            metadata=metadata)
         if is_blocking:
             print("Finished transaction!")
         else:
             print("Transaction submitted to validator")
         print(
             "To query for transaction status, run: query txn_acc_seq {} {} \
-            <fetch_events=true|false>".format(
+            <include_events=true|false>".format(
                 params[1], sequence_number
             )
         )
