@@ -22,7 +22,7 @@ def test_get_transaction():
     c = libra_client.Client("testnet")
     stx = c.get_transaction(1, True)
     assert stx.transaction.type == 'blockmetadata'
-    assert stx.vm_status == 'executed'
+    assert stx.vm_status.type == 'executed'
     assert stx.success is True
     # assert stx.gas_used == 600
 
@@ -148,7 +148,7 @@ def test_client_testnet():
     c2 = libra_client.Client("testnet")
     if 'TESTNET_LOCAL' in os.environ:
         return
-    assert c2.url == "https://client.testnet.libra.org"
+    assert c2.url == "https://client.testnet.libra.org/v1"
     assert c2.verbose == True
     assert c2.faucet_account is None
 
